'use client';

import { useEffect, useState } from 'react';
import { Button } from 'antd';
import { useSelectedLayoutSegment, usePathname } from 'next/navigation';
import { Link } from '../../i18n/routing';
import { AUTH_TOKEN_KEY, AUTH_USER } from '../../constants/common';
import {deleteStorageKey, useLocalStorage} from '../../hooks/useLocalStorage';
import { i18nText } from '../../i18nKeys';
import { getMenuConfig } from '../../utils/account';
import { getChatList } from '../../actions/chat/groups';

export const AccountMenu = ({ locale }: { locale: string }) => {
    const selectedLayoutSegment = useSelectedLayoutSegment();
    const pathname = selectedLayoutSegment || '';
    const paths = usePathname();
    const menu: { path: string, title: string, count?: number }[] = getMenuConfig(locale);
    const [counts, setCounts] = useState<any>({});

    const onLogout = () => {
        deleteStorageKey(AUTH_TOKEN_KEY);
        deleteStorageKey(AUTH_USER);
        window?.location?.replace(`/${paths.split('/')[1]}/`);
    };
    const [jwt] = useLocalStorage(AUTH_TOKEN_KEY, '');
    let init = false
    useEffect(() => {
        if (jwt && locale && !init) {
            init = true;
            getChatList(locale, jwt).then((payload: any)=> {
                if (payload?.directs) {
                    let summ = 0;
                    payload?.directs.forEach((el: any) => {
                        summ = summ + el.newMessagesCount
                    })
                    setCounts({'messages': summ})
                }
            })
        }
    }, [jwt, locale])

    const getterCount =  (path: string, count: number)=> {
        return counts[path]? counts[path] : count
    }

    return (
        <ul className="list-sidebar">
            {menu.map(({ path, title, count }) => (
                <li key={path} className="list-sidebar__item">
                    <Link href={`/account/${path}` as any} className={path === pathname ? 'active' : ''}>
                        {title}
                        {getterCount(path, count) ? (
                            <span className="count">{getterCount(path, count)}</span>
                        ) : null}
                    </Link>
                </li>
            ))}
            <li className="list-sidebar__item">
                <Button
                    type="link"
                    onClick={onLogout}
                    className="b-button__logout"
                >
                    {i18nText('logout', locale)}
                </Button>
            </li>
        </ul>
    );
};
